@@ -25,16 +25,17 @@ from tests.utils import asyncio_patch, AsyncioMagicMock
 
 from gns3server.ubridge.ubridge_error import UbridgeNamespaceError
 from gns3server.compute.docker.docker_vm import DockerVM
-from gns3server.compute.docker.docker_error import DockerError, DockerHttp404Error, DockerHttp304Error
+from gns3server.compute.docker.docker_error import DockerError, DockerHttp404Error
 from gns3server.compute.docker import Docker
-from gns3server.utils.get_resource import get_resource
-
 
 from unittest.mock import patch, MagicMock, call
 
 
+pytestmark = pytest.mark.skipif(sys.platform.startswith("win"), reason="Not supported on Windows")
+
+
 @pytest.fixture()
-async def manager(loop, port_manager):
+async def manager(port_manager):
 
     m = Docker.instance()
     m.port_manager = port_manager
@@ -42,7 +43,7 @@ async def manager(loop, port_manager):
 
 
 @pytest.fixture(scope="function")
-async def vm(loop, compute_project, manager):
+async def vm(compute_project, manager):
 
     vm = DockerVM("test", str(uuid.uuid4()), compute_project, manager, "ubuntu:latest")
     vm._cid = "e90e34656842"
@@ -101,7 +102,7 @@ async def test_create(compute_project, manager):
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
                         ],
                         "Privileged": True
@@ -139,7 +140,7 @@ async def test_create_with_tag(compute_project, manager):
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
                         ],
                         "Privileged": True
@@ -180,9 +181,9 @@ async def test_create_vnc(compute_project, manager):
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
-                            '/tmp/.X11-unix/:/tmp/.X11-unix/'
+                            "/tmp/.X11-unix/X{0}:/tmp/.X11-unix/X{0}:ro".format(vm._display)
                         ],
                         "Privileged": True
                     },
@@ -222,6 +223,21 @@ async def test_create_with_extra_hosts(compute_project, manager):
         assert vm._extra_hosts == extra_hosts
 
 
+async def test_create_with_colon_in_project_name(compute_project, manager):
+
+    response = {
+        "Id": "e90e34656806",
+        "Warnings": []
+    }
+
+    with asyncio_patch("gns3server.compute.docker.Docker.list_images", return_value=[{"image": "ubuntu"}]):
+        with asyncio_patch("gns3server.compute.docker.Docker.query", return_value=response):
+            with patch("gns3server.compute.project.Project.node_working_directory", return_value="/tmp/test_:_/"):
+                vm = DockerVM("test", str(uuid.uuid4()), compute_project, manager, "ubuntu")
+                with pytest.raises(DockerError):
+                    await vm.create()
+
+
 async def test_create_with_extra_hosts_wrong_format(compute_project, manager):
     extra_hosts = "test"
 
@@ -295,7 +311,7 @@ async def test_create_start_cmd(compute_project, manager):
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
                         ],
                         "Privileged": True
@@ -393,7 +409,7 @@ async def test_create_image_not_available(compute_project, manager):
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
                         ],
                         "Privileged": True
@@ -436,7 +452,7 @@ async def test_create_with_user(compute_project, manager):
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
                         ],
                         "Privileged": True
@@ -518,7 +534,7 @@ async def test_create_with_extra_volumes_duplicate_1_image(compute_project, mana
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
                             "{}:/gns3volumes/vol/1".format(os.path.join(vm.working_dir, "vol", "1")),
                         ],
@@ -557,7 +573,7 @@ async def test_create_with_extra_volumes_duplicate_2_user(compute_project, manag
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
                             "{}:/gns3volumes/vol/1".format(os.path.join(vm.working_dir, "vol", "1")),
                         ],
@@ -596,7 +612,7 @@ async def test_create_with_extra_volumes_duplicate_3_subdir(compute_project, man
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
                             "{}:/gns3volumes/vol".format(os.path.join(vm.working_dir, "vol")),
                         ],
@@ -635,7 +651,7 @@ async def test_create_with_extra_volumes_duplicate_4_backslash(compute_project,
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
                             "{}:/gns3volumes/vol".format(os.path.join(vm.working_dir, "vol")),
                         ],
@@ -674,7 +690,7 @@ async def test_create_with_extra_volumes_duplicate_5_subdir_issue_1595(compute_p
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc".format(os.path.join(vm.working_dir, "etc")),
                         ],
                         "Privileged": True
@@ -712,7 +728,7 @@ async def test_create_with_extra_volumes_duplicate_6_subdir_issue_1595(compute_p
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc".format(os.path.join(vm.working_dir, "etc")),
                         ],
                         "Privileged": True
@@ -756,7 +772,7 @@ async def test_create_with_extra_volumes(compute_project, manager):
                     {
                         "CapAdd": ["ALL"],
                         "Binds": [
-                            "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                            "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
                             "{}:/gns3volumes/vol/1".format(os.path.join(vm.working_dir, "vol", "1")),
                             "{}:/gns3volumes/vol/2".format(os.path.join(vm.working_dir, "vol", "2")),
@@ -839,7 +855,7 @@ async def test_unpause(vm):
     mock.assert_called_with("POST", "containers/e90e34656842/unpause")
 
 
-async def test_start(vm, manager, free_console_port):
+async def test_start(vm, manager, free_console_port, tmpdir):
 
     assert vm.status != "started"
     vm.adapters = 1
@@ -867,6 +883,31 @@ async def test_start(vm, manager, free_console_port):
     assert vm.status == "started"
 
 
+async def test_resources_installed(vm, manager, tmpdir):
+
+    assert vm.status != "started"
+    vm.adapters = 1
+
+    docker_resources_path = os.path.join(tmpdir, "docker", "resources")
+    os.makedirs(docker_resources_path, exist_ok=True)
+    manager.resources_path = MagicMock(return_value=docker_resources_path)
+
+    with asyncio_patch("gns3server.compute.docker.DockerVM._get_container_state", return_value="stopped"):
+        with asyncio_patch("gns3server.compute.docker.Docker.query"):
+            with asyncio_patch("gns3server.compute.docker.DockerVM._start_ubridge"):
+                with asyncio_patch("gns3server.compute.docker.DockerVM._get_namespace", return_value=42):
+                    with asyncio_patch("gns3server.compute.docker.DockerVM._add_ubridge_connection"):
+                        with asyncio_patch("gns3server.compute.docker.DockerVM._start_console"):
+                            await vm.start()
+
+    assert vm.status == "started"
+    assert os.path.exists(os.path.join(docker_resources_path, "init.sh"))
+    assert os.path.exists(os.path.join(docker_resources_path, "run-cmd.sh"))
+    assert os.path.exists(os.path.join(docker_resources_path, "bin", "busybox"))
+    assert os.path.exists(os.path.join(docker_resources_path, "bin", "udhcpc"))
+    assert os.path.exists(os.path.join(docker_resources_path, "etc", "udhcpc", "default.script"))
+
+
 async def test_start_namespace_failed(vm, manager, free_console_port):
 
     assert vm.status != "started"
@@ -981,7 +1022,7 @@ async def test_update(vm):
         {
             "CapAdd": ["ALL"],
             "Binds": [
-                "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                "{}:/gns3:ro".format(Docker.resources_path()),
                 "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
             ],
             "Privileged": True
@@ -1049,7 +1090,7 @@ async def test_update_running(vm):
         {
             "CapAdd": ["ALL"],
             "Binds": [
-                "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+                "{}:/gns3:ro".format(Docker.resources_path()),
                 "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
             ],
             "Privileged": True
@@ -1100,8 +1141,7 @@ async def test_close(vm, port_manager):
 async def test_close_vnc(vm):
 
     vm._console_type = "vnc"
-    vm._x11vnc_process = MagicMock()
-    vm._xvfb_process = MagicMock()
+    vm._vnc_process = MagicMock()
 
     with asyncio_patch("gns3server.compute.docker.DockerVM._get_container_state", return_value="stopped"):
         with asyncio_patch("gns3server.compute.docker.Docker.query") as mock_query:
@@ -1109,7 +1149,7 @@ async def test_close_vnc(vm):
         mock_query.assert_called_with("DELETE", "containers/e90e34656842", params={"force": 1, "v": 1})
 
     assert vm._closed is True
-    assert vm._xvfb_process.terminate.called
+    assert vm._vnc_process.terminate.called
 
 
 async def test_get_namespace(vm):
@@ -1311,7 +1351,7 @@ async def test_mount_binds(vm):
 
     dst = os.path.join(vm.working_dir, "test/experimental")
     assert vm._mount_binds(image_infos) == [
-        "{}:/gns3:ro".format(get_resource("compute/docker/resources")),
+        "{}:/gns3:ro".format(Docker.resources_path()),
         "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
         "{}:/gns3volumes{}".format(dst, "/test/experimental")
     ]
