@@ -33,7 +33,7 @@ from gns3server.utils.asyncio import aiozipstream
 
 
 @pytest.fixture
-async def project(loop, controller):
+async def project(controller):
 
     p = Project(controller=controller, name="test")
     p.dump = MagicMock()
@@ -111,6 +111,7 @@ async def test_export(tmpdir, project):
         f.write("HELLO")
     with open(os.path.join(path, "vm-1", "dynamips", "test_log.txt"), 'w+') as f:
         f.write("LOG")
+    os.makedirs(os.path.join(path, "vm-1", "dynamips", "empty-dir"))
     os.makedirs(os.path.join(path, "project-files", "snapshots"))
     with open(os.path.join(path, "project-files", "snapshots", "test"), 'w+') as f:
         f.write("WORLD")
@@ -127,6 +128,7 @@ async def test_export(tmpdir, project):
 
         assert 'test.gns3' not in myzip.namelist()
         assert 'project.gns3' in myzip.namelist()
+        assert 'vm-1/dynamips/empty-dir/' in myzip.namelist()
         assert 'project-files/snapshots/test' not in myzip.namelist()
         assert 'vm-1/dynamips/test_log.txt' not in myzip.namelist()
 
@@ -323,7 +325,7 @@ async def test_export_with_images(tmpdir, project):
         myzip.getinfo("images/IOS/test.image")
 
 
-async def test_export_keep_compute_id(tmpdir, project):
+async def test_export_keep_compute_ids(tmpdir, project):
     """
     If we want to restore the same computes we could ask to keep them
     in the file
@@ -352,7 +354,7 @@ async def test_export_keep_compute_id(tmpdir, project):
         json.dump(data, f)
 
     with aiozipstream.ZipFile() as z:
-        await export_project(z, project, str(tmpdir), keep_compute_id=True)
+        await export_project(z, project, str(tmpdir), keep_compute_ids=True)
         await write_file(str(tmpdir / 'zipfile.zip'), z)
 
     with zipfile.ZipFile(str(tmpdir / 'zipfile.zip')) as myzip:
@@ -456,7 +458,7 @@ async def test_export_with_ignoring_snapshots(tmpdir, project):
     Path(os.path.join(snapshots_dir, 'snap.gns3project')).touch()
 
     with aiozipstream.ZipFile() as z:
-        await export_project(z, project, str(tmpdir), keep_compute_id=True)
+        await export_project(z, project, str(tmpdir), keep_compute_ids=True)
         await write_file(str(tmpdir / 'zipfile.zip'), z)
 
     with zipfile.ZipFile(str(tmpdir / 'zipfile.zip')) as myzip:
